#!/bin/bash

MODE=""
BASE=$(cd $(dirname $0); pwd)
INST_CONF="/etc/logger"
INST_EXEC="/usr/local/sbin"

declare -a CATEGORY=(
	["1"]="CentOS"
	["2"]="Debian"
	["3"]="openSUSE"
	["4"]="RHEL"
)


## OS Type Check
##
# CentOS
if [ -f /etc/centos-release ]; then
	cat /etc/centos-release | grep CentOS > /dev/null 2>&1
	[ $? -eq 0 ] && MODE=1;
fi

# Debian
if [ -f /etc/os-release ]; then
	cat /etc/os-release | grep Debian > /dev/null 2>&1
	[ $? -eq 0 ] && MODE=2;
fi

# openSUSE
if [ -f /etc/os-release ]; then
	cat /etc/os-release | grep openSUSE > /dev/null 2>&1
	[ $? -eq 0 ] && MODE=3;
fi

# RHEL
if [ -f /etc/redhat-release ]; then
	cat /etc/redhat-release | grep 'Red Hat Enterprise' > /dev/null 2>&1
	[ $? -eq 0 ] && MODE=4;
fi

# ERROR
if [ -z "$MODE" ]; then
	echo "ERROR: OS Type Mismatch"
	exit 1
fi


## logger daemon install
##
echo "Install Mode: ${CATEGORY[$MODE]}"

# SCRIPT
cp -af $BASE/logger-exec $INST_EXEC

# CONFIG
[ ! -e $INST_CONF ] && mkdir -p $INST_CONF
if [ -f $INST_CONF/logger.conf ]; then
	cp -af $BASE/logger.conf $INST_CONF/logger.conf.new
	chown root.root $INST_CONF/logger.conf.new
	chmod 644 $INST_CONF/logger.conf.new
else
	cp -af $BASE/logger.conf $INST_CONF/logger.conf
	chown root.root $INST_CONF/logger.conf
	chmod 644 $INST_CONF/logger.conf
fi

# INIT/ENV
if [ $MODE -eq 1 ]; then
	cp -af $BASE/environment/logger.init.sysconfig /etc/sysconfig/logger
	cp -af $BASE/service/logger.centos /etc/init.d/logger
	chkconfig --add logger > /dev/null 2>&1
fi
if [ $MODE -eq 2 ]; then
	cp -af $BASE/environment/logger.init.default /etc/default/logger
	cp -af $BASE/service/logger.debian /etc/init.d/logger
	chkconfig logger on > /dev/null 2>&1
fi
if [ $MODE -eq 3 ]; then
	cp -af $BASE/environment/logger.init.sysconfig /etc/sysconfig/logger
	cp -af $BASE/service/logger.opensuse /etc/init.d/logger
	chkconfig --add logger > /dev/null 2>&1
fi
if [ $MODE -eq 4 ]; then
	cp -af $BASE/environment/logger.systemd.sysconfig /etc/sysconfig/logger
	cp -af $BASE/service/logger.rhel /usr/lib/systemd/system/logger.service
	systemctl enable logger.service > /dev/null 2>&1
fi
[ -f /etc/init.d/logger    ] && chmod 755 /etc/init.d/logger    && chown root.root /etc/init.d/logger
[ -f /etc/sysconfig/logger ] && chmod 644 /etc/sysconfig/logger && chown root.root /etc/sysconfig/logger
[ -f /etc/default/logger   ] && chmod 644 /etc/default/logger   && chown root.root /etc/default/logger
[ -f /usr/lib/systemd/system/logger.service ] && chmod 644 /usr/lib/systemd/system/logger.service \
                                              && chown root.root /usr/lib/systemd/system/logger.service

# RELOAD
which systemctl > /dev/null 2>&1
if [ $? -eq 0 ]; then
	systemctl daemon-reload
fi

exit 0
